#
# spec file for package python-gnome-extras
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define build_gdl 0
%define build_gtkmozembed 0

%if 0%{suse_version} > 1130
%define xulrunner_version 20
%else
%if 0%{suse_version} > 1120
%define xulrunner_version 192
%else
%if 0%{suse_version} > 1110
%define xulrunner_version 191
%else
%define xulrunner_version 190
%endif
%endif
%endif

Name:           python-gnome-extras
%define _name   gnome-python-extras
Version:        2.25.3
Release:        3.18
Summary:        Python bindings for GNOME
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/Python
Url:            ftp://ftp.gnome.org/pub/gnome/sources/gnome-python-extras
Source:         %{_name}-%{version}.tar.bz2
Source1:        README.openSUSE
# PATCH-FIX-UPSTREAM xulrunner19.patch bgo532856 bnc480992 wr@opensuse.org -- Make gtkembedmoz work with xulrunner 1.9
Patch0:         xulrunner19.patch
# PATCH-FIX-UPSTREAM python-gnome-extras-gdl.patch vuntz@opensuse.org -- Taken from git, to fix build of gdl bindings
Patch1:         python-gnome-extras-gdl.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
%if %{build_gdl}
BuildRequires:  gdl-devel
%endif
BuildRequires:  gtk-doc
BuildRequires:  gtk2-devel
BuildRequires:  gtkspell-devel
BuildRequires:  libgnomeui-devel
%if %{build_gtkmozembed}
BuildRequires:  mozilla-xulrunner%{xulrunner_version}-devel
%endif
BuildRequires:  python-devel
BuildRequires:  python-gnome-devel
%if %suse_version <= 1130
# Needed for the documentation to build:
BuildRequires:  python-gobject2-doc
%endif
# Explicitly require all subpackages, so packages depending on
# python-gnome-extras get all modules.
Requires:       python-egg
%if %{build_gdl}
Requires:       python-gdl
%endif
%if %{build_gtkmozembed}
Requires:       python-gtkmozembed
%endif
Requires:       python-gtkspell
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNOME-python-extras is an extension module for python that gives you
access to more GNOME libraries.  This means you have access to more
widgets, simple configuration interface, metadata support and many
other features.

%package -n python-egg
Summary:        Python bindings for libegg widgets
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/Python
Requires:       python-bonobo
Requires:       python-gtk
%py_requires

%description -n python-egg
This package contains Python bindings for some libegg widgets.

Note that libegg use is generally not advised.

%if %{build_gdl}

%package -n python-gdl
Summary:        Python bindings for GDL
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Requires:       python-gtk
%py_requires

%description -n python-gdl
This package contains Python bindings for GDL.
%endif

%if %{build_gtkmozembed}

%package -n python-gtkmozembed
Summary:        Python bindings for GtkMozEmbed
License:        LGPL-2.1+
Group:          Development/Libraries/Python
Requires:       mozilla-xulrunner%{xulrunner_version}
Requires:       python-gtk
%py_requires

%description -n python-gtkmozembed
This package contains Python bindings for GtkMozEmbed.
%endif

%package -n python-gtkspell
Summary:        Python bindings for GtkSpell
License:        GPL-2.0+
Group:          Development/Libraries/Python
Requires:       python-gtk
%py_requires

%description -n python-gtkspell
This package contains Python bindings for GtkSpell.

%package devel
Summary:        Python bindings for GNOME
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/Python
# This will bring in all subpackages
Requires:       %{name} = %{version}
Requires:       python-gobject2-devel
Provides:       python-gnome-extras-doc = 2.25.2
Obsoletes:      python-gnome-extras-doc < 2.25.2

%description devel
GNOME-python-extras is an extension module for python that gives you
access to more GNOME libraries.  This means you have access to more
widgets, simple configuration interface, metadata support and many
other features.

%prep
%setup -q -n %{_name}-%{version}
cp -a %{S:1} .
%patch0 -p1
%patch1 -p1

%build
autoreconf -i -f
# We don't care about gtkhtml2 anymore.
%configure --enable-docs \
        --disable-gtkhtml2
make %{?jobs:-j%jobs}

%install
%makeinstall
for dir in %{py_sitedir} ; do
    find %{buildroot}/$dir \( -name '*.py[co]' -o -name '*.la' \) -print0 | xargs -0 rm
    python %{_libdir}/python%{py_ver}/compileall.py -d $dir %{buildroot}/$dir
done
# Remove examples for bindings we don't ship
rm -r examples/{gksu2,gtkhtml2}
%fdupes %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING.GPL COPYING.LGPL ChangeLog NEWS README README.openSUSE
# Please list modules explicitly, do not use wildcards!

%files -n python-egg
%defattr(-, root, root)
%doc COPYING.GPL COPYING.LGPL
%dir %{py_sitedir}/gtk-2.0/egg
%{py_sitedir}/gtk-2.0/egg/__init__.py*
%{py_sitedir}/gtk-2.0/egg/recent.so
%{py_sitedir}/gtk-2.0/egg/trayicon.so

%if %{build_gdl}

%files -n python-gdl
%defattr(-, root, root)
%doc COPYING.LGPL
%{py_sitedir}/gtk-2.0/gdl.so
%endif

%if %{build_gtkmozembed}

%files -n python-gtkmozembed
%defattr(-, root, root)
%doc COPYING.LGPL
%{py_sitedir}/gtk-2.0/gtkmozembed.so
%endif

%files -n python-gtkspell
%defattr(-, root, root)
%doc COPYING.GPL
%{py_sitedir}/gtk-2.0/gtkspell.so

%files devel
%defattr(-, root, root)
%doc examples/
%{_libdir}/pkgconfig/gnome-python-extras-2.0.pc
# we explicitly list the directories here to be sure we don't include something
# that should live in the main package
%dir %{_datadir}/pygtk
%dir %{_datadir}/pygtk/2.0
%{_datadir}/pygtk/2.0/defs/
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%if %{build_gtkmozembed}
%{_datadir}/gtk-doc/html/pygtkmozembed/
%endif
%{_datadir}/gtk-doc/html/pygtkspell/

%changelog
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jun  7 2011 dimstar@opensuse.org
- Drop -gda subpackage. No longer needed, as libgda supports
  gobject-introspection and this is the preferred way to interact
  with it from python now.
- Remove libgda-4_0-devel BuildRequires and the various gda related
  Requires in the -devel package.
* Tue Apr 26 2011 vuntz@opensuse.org
- Add build_gdl/build_gtkmozembed defines to decide whether to
  build gdl and gtkmozembed bindings.
- Set build_gdl to 0 as gdl now has introspection support and the
  bindings don't support the latest gdl.
- Set build_gtkmozembed to 0 as mozilla announced they're dropping
  support for gtkmozembed.
* Mon Jan 17 2011 vuntz@opensuse.org
- Fix python-gda to have a python-gobject2 Requires instead of
  python-gobject, since the renaming to python-gobject hasn't
  happened yet.
* Fri Jan  7 2011 vuntz@opensuse.org
- Split all python modules in subpackages, so we can have more
  fine-grained dependencies:
  + Create python-egg, python-gdl, python-gtkmozembed,
    python-gtkspell, python-gda subpackages.
  + Move all Requires to the relevant subpackages.
  + Ship a README.openSUSE file explaining the setup of the
    package.
- Move code examples to the devel subpackage.
- Stop removing gksu bindings: they're not installed anymore.
- Add fdupes BuildRequires and use %%fdupes.
* Thu Dec  9 2010 vuntz@opensuse.org
- Build against mozilla-xulrunner20-devel on 11.4 and later.
* Sun Aug  8 2010 vuntz@opensuse.org
- Move some files to devel subpackage.
* Sun Aug  8 2010 vuntz@opensuse.org
- Only have a python-gobject2-doc BuildRequires on openSUSE 11.3
  and earlier: starting with 11.4, this package is merged in
  python-gobject2-devel.
* Wed Feb 10 2010 vuntz@opensuse.org
- Drop libgtkhtml-devel BuildRequires: we stop building the
  gtkhtml2 bindings, so we can remove the library from openSUSE.
  Add --disable-gtkhtml2 to configure to make this explicit.
- Add python-gnome-extras-gdl.patch: taken from upstream, to fix
  build of gdl bindings. Also remove --disable-gdl from configure.
* Thu Jan  7 2010 vuntz@opensuse.org
- Build against mozilla-xulrunner192-devel on openSUSE > 11.2.
- Fix self-obsoletion of python-gnome-extras-doc.
* Thu May 28 2009 vuntz@novell.com
- Do not build the gdl bindings: they fail to build with latest
  gdl.
* Wed May  6 2009 vuntz@novell.com
- Build against mozilla-xulrunner190 on openSUSE <= 11.1.
* Wed May  6 2009 vuntz@novell.com
- Review changes.
* Mon May  4 2009 wr@opensuse.org
- Add xulrunner19.patch: make gtkembedmoz work with XULRunner 1.9's
  XPCOM_GLUE (bnc#480992, bgo#532856)
- Build against mozilla-xulrunner191
* Fri Apr  3 2009 vuntz@novell.com
- Remove python-numeric Requires: there's no reference to it
  anywhere in the code, so it wasn't needed.
* Wed Feb 18 2009 mboman@suse.de
- Add back libgnomeui-devel. Was needed for gtk-2.0/egg/recent.so
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.3:
  + gda: Now requires and builds with the latest libgda (3.99.11)
- Merge -doc into -devel since it only contained gtk-doc
- Remove libbonoboui-devel and libgnomeui-devel from BuildRequires
* Sat Feb 14 2009 vuntz@novell.com
- Package the files for the gda bindings now that we have a recent
  enough version of libgda.
* Wed Feb  4 2009 vuntz@novell.com
- Remove BuildRequires on gnome-vfs2-devel and add one on
  gdl-devel.
- Add --enable-docs to configure and add BuildRequires on
  python-gobject2-doc to haveit work.
- We don't have the gda bindings in this release, but we should
  make sure they come back when we have a newer libgda.
* Wed Feb  4 2009 vuntz@novell.com
- Update to version 2.25.2:
  + gda: Now requires and builds with the latest libgda (3.99.9)
- Changes from version 2.25.1:
  + gda:
  - pygda-3.0 is now replaced by pygda-4.0, wrapping libgda-4.0 instead of
    libgda-3.0, with various API changes.
  - On windows, install gda.pyd instead of gda.dll, as expected by Python on
    Windows, along with some other Windows fixes.
  + Fixed the gdl build.
  + gtkmozembed:
  - Fix the build with XUL 1.9.
  - Wrap gtk_moz_embed_set_path(). bgo#400861, bgo#503067
  + Build:
  - Allow the build and install of some modules to be disabled to make
    life easier for distro packagers. bgo#534307
  - Allow documentation building to be disabled.
  - Use python-config to get python includes. bgo#448182.
* Thu Jan 29 2009 vuntz@novell.com
- BuildRequires libgda-4_0-devel.
* Thu Nov  6 2008 maw@suse.de
- Split out a -devel subpackage to reduce the main package's
  requirements.
* Wed Nov  5 2008 maw@suse.de
- Require libgda-3_0-devel
- Don't run autoreconf.
* Wed Jul 23 2008 coolo@suse.de
- build against xulrunner190
* Tue Oct 16 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Fri Oct 12 2007 sbrabec@suse.cz
- Updated to version 2.19.1:
  * egg.trayicon: By popular demand, undeprecate this, at least
    until Gtk+ adds all the functionality to GtkStatusIcon; apply
    upstream patch to enable transparent icons
  * gda: Now use libgda-3.0 instead of libgda-1.2. This breaks API;
    make it explicit that the license is LGPL
  * gksu2: New module, Various fixes; build gksu conditionally,
    like it was supposed to all along
  * gtkhtml2: Check for errors in html_document_open_stream; fix
    the example
  * gdl: Support the gdl 0.7.x API, in addtion to 0.6.x
* Wed Mar  7 2007 jhargadon@suse.de
- added more verbose statements in the %%files section of the
  specfile to resolve bug #224800
* Tue Feb  6 2007 jhargadon@suse.de
- added back a line in the specfile to remove gksu module that was
  accidentally removed in the last update.
* Thu Feb  1 2007 sbrabec@suse.cz
- Removed remaining references to /opt/gnome.
- Build python-gnome-extras-doc as a separate package.
* Mon Dec  4 2006 jhargadon@suse.de
- added mozilla-xulrunner to BuildRequires to enable gtkmozembed
  (#224800)
- removed unused BuildRequires
- removed gksu module (#225388)
* Thu Aug 17 2006 cthiel@suse.de
- fix build
* Wed Aug 16 2006 cthiel@suse.de
- update to version 2.14.2
  * Correct gnome-python defsdir detection, fixes build breakage
- Overview of Changes from 2.14.0 to 2.14.1
  * Mac OS X build fixes
  * Allow building gtkmozembed against xulrunner
- Overview of Changes from 2.13.3 to 2.14.0
  * Fixed some crashes due to missing parameter type checking
- Overview of Changes from 2.13.2 to 2.13.3
  * The following modules moved to the package gnome-python-desktop:
  - gnomeapplet
  - gnomeprint, gnomeprint.ui
  - gtksourceview
  - wnck
  - totem.plparser
  - gtop
  - nautilusburn
  - mediaprofiles
  * Correct a typo in pygda-1.2.pc
- Overview of Changes from 2.13.1 to 2.13.2
  * Wrap panel_applet_set_background_widget
  * Revert back to wrapping pygda 1.2 due to API instability of 2.0
  * Add new metacity bindings
  * Update eggrecent code from CVS
- Overview of Changes from 2.13.0 to 2.13.1
  * Register missing wnck constants
- Overview of Changes from 2.12.1 to 2.13.0
  * Require libgda 2.0 instead of 1.2
  * Wrap panel_applet_get_background
  * Wrap egg_recent_model_get_list
  * Wrap wnck_tasklist_get_size_hint_list
  * Double-free fixes
* Mon Feb 20 2006 ro@suse.de
- added libstdc++-devel to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  1 2005 gekker@suse.de
- Update to version 2.12.1
* Sun Oct 23 2005 ro@suse.de
- added hal/hal-devel to nfb
* Fri Oct 14 2005 ro@suse.de
- removed libzvt from neededforbuild (unused)
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.3
- Enable more modules
* Mon Jun 13 2005 gekker@suse.de
- Initial import, version 2.10.2
